@@ -22,7 +22,9 @@
 # Copyright 2021 Steve Kowalik <steven@wedontsleep.org>                        #
 # Copyright 2023 Enrico Minack <github@enrico.minack.dev>                      #
 # Copyright 2023 Trim21 <trim21.me@gmail.com>                                  #
+# Copyright 2024 Enrico Minack <github@enrico.minack.dev>                      #
 # Copyright 2024 Jirka Borovec <6035284+Borda@users.noreply.github.com>        #
+# Copyright 2024 Ramiro Morales <ramiro@users.noreply.github.com>              #
 #                                                                              #
 # This file is part of PyGithub.                                               #
 # http://pygithub.readthedocs.io/                                              #
@@ -58,9 +60,11 @@ class RepositoryKey(CompletableGithubObject):
     """
 
     def _initAttributes(self) -> None:
+        self._added_by: Attribute[str] = NotSet
         self._created_at: Attribute[datetime] = NotSet
         self._id: Attribute[int] = NotSet
         self._key: Attribute[str] = NotSet
+        self._last_used: Attribute[datetime] = NotSet
         self._title: Attribute[str] = NotSet
         self._url: Attribute[str] = NotSet
         self._verified: Attribute[bool] = NotSet
@@ -69,6 +73,11 @@ class RepositoryKey(CompletableGithubObject):
     def __repr__(self) -> str:
         return self.get__repr__({"id": self._id.value, "title": self._title.value})
 
+    @property
+    def added_by(self) -> str:
+        self._completeIfNotSet(self._added_by)
+        return self._added_by.value
+
     @property
     def created_at(self) -> datetime:
         self._completeIfNotSet(self._created_at)
@@ -84,6 +93,11 @@ class RepositoryKey(CompletableGithubObject):
         self._completeIfNotSet(self._key)
         return self._key.value
 
+    @property
+    def last_used(self) -> datetime:
+        self._completeIfNotSet(self._last_used)
+        return self._last_used.value
+
     @property
     def title(self) -> str:
         self._completeIfNotSet(self._title)
@@ -111,12 +125,17 @@ class RepositoryKey(CompletableGithubObject):
         headers, data = self._requester.requestJsonAndCheck("DELETE", self.url)
 
     def _useAttributes(self, attributes: Dict[str, Any]) -> None:
+        if "added_by" in attributes:  # pragma no branch
+            self._added_by = self._makeStringAttribute(attributes["added_by"])
         if "created_at" in attributes:  # pragma no branch
             self._created_at = self._makeDatetimeAttribute(attributes["created_at"])
         if "id" in attributes:  # pragma no branch
             self._id = self._makeIntAttribute(attributes["id"])
         if "key" in attributes:  # pragma no branch
             self._key = self._makeStringAttribute(attributes["key"])
+        if "last_used" in attributes:  # pragma no branch
+            assert attributes["last_used"] is None or isinstance(attributes["last_used"], str), attributes["last_used"]
+            self._last_used = self._makeDatetimeAttribute(attributes["last_used"])
         if "title" in attributes:  # pragma no branch
             self._title = self._makeStringAttribute(attributes["title"])
         if "url" in attributes:  # pragma no branch
