@@ -16,10 +16,31 @@
 # Copyright 2018 James D'Amato <james.j.damato@gmail.com>                      #
 # Copyright 2018 Maarten Fonville <mfonville@users.noreply.github.com>         #
 # Copyright 2018 Manu Hortet <manuhortet@gmail.com>                            #
-# Copyright 2018 Michał Górny <mgorny@gentoo.org>                            #
+# Copyright 2018 Michał Górny <mgorny@gentoo.org>                              #
 # Copyright 2018 Steve Kowalik <steven@wedontsleep.org>                        #
 # Copyright 2018 Tim Boring <tboring@hearst.com>                               #
+# Copyright 2018 Wan Liuyang <tsfdye@gmail.com>                                #
 # Copyright 2018 sfdye <tsfdye@gmail.com>                                      #
+# Copyright 2019 Adam Baratz <adam.baratz@gmail.com>                           #
+# Copyright 2019 Shibasis Patel <smartshibasish@gmail.com>                     #
+# Copyright 2019 Steve Kowalik <steven@wedontsleep.org>                        #
+# Copyright 2019 Wan Liuyang <tsfdye@gmail.com>                                #
+# Copyright 2020 Adrian Bridgett <58699309+tl-adrian-bridgett@users.noreply.github.com>#
+# Copyright 2020 Andy Grunwald <andygrunwald@gmail.com>                        #
+# Copyright 2020 Gilad Shefer <giladshefer@gmail.com>                          #
+# Copyright 2020 Steve Kowalik <steven@wedontsleep.org>                        #
+# Copyright 2020 Tal Machani <12785464+talmachani@users.noreply.github.com>    #
+# Copyright 2021 Mark Walker <mark.walker@realbuzz.com>                        #
+# Copyright 2021 Steve Kowalik <steven@wedontsleep.org>                        #
+# Copyright 2021 秋葉 <ambiguous404@gmail.com>                                   #
+# Copyright 2023 Enrico Minack <github@enrico.minack.dev>                      #
+# Copyright 2023 Jirka Borovec <6035284+Borda@users.noreply.github.com>        #
+# Copyright 2023 Kevin Grandjean <Muscaw@users.noreply.github.com>             #
+# Copyright 2023 Mark Amery <markamery@btinternet.com>                         #
+# Copyright 2023 Trim21 <trim21.me@gmail.com>                                  #
+# Copyright 2024 Andrii Kezikov <cheshirez@gmail.com>                          #
+# Copyright 2024 Enrico Minack <github@enrico.minack.dev>                      #
+# Copyright 2024 Jirka Borovec <6035284+Borda@users.noreply.github.com>        #
 #                                                                              #
 # This file is part of PyGithub.                                               #
 # http://pygithub.readthedocs.io/                                              #
@@ -38,8 +59,10 @@
 # along with PyGithub. If not, see <http://www.gnu.org/licenses/>.             #
 #                                                                              #
 ################################################################################
+
 from __future__ import annotations
 
+import urllib.parse
 from typing import TYPE_CHECKING, Any
 
 from deprecated import deprecated
@@ -65,7 +88,11 @@ if TYPE_CHECKING:
 
 class Team(CompletableGithubObject):
     """
-    This class represents Teams. The reference can be found here https://docs.github.com/en/rest/reference/teams
+    This class represents Teams.
+
+    The reference can be found here
+    https://docs.github.com/en/rest/reference/teams
+
     """
 
     def _initAttributes(self) -> None:
@@ -74,6 +101,7 @@ class Team(CompletableGithubObject):
         self._members_url: Attribute[str] = NotSet
         self._name: Attribute[str] = NotSet
         self._description: Attribute[str] = NotSet
+        self._notification_setting: Attribute[str] = NotSet
         self._permission: Attribute[str] = NotSet
         self._repos_count: Attribute[int] = NotSet
         self._repositories_url: Attribute[str] = NotSet
@@ -112,6 +140,11 @@ class Team(CompletableGithubObject):
         self._completeIfNotSet(self._description)
         return self._description.value
 
+    @property
+    def notification_setting(self) -> str:
+        self._completeIfNotSet(self._notification_setting)
+        return self._notification_setting.value
+
     @property
     def permission(self) -> str:
         self._completeIfNotSet(self._permission)
@@ -193,6 +226,8 @@ class Team(CompletableGithubObject):
         assert isinstance(member, str) or isinstance(member, github.NamedUser.NamedUser), member
         if isinstance(member, github.NamedUser.NamedUser):
             member = member._identity
+        else:
+            member = urllib.parse.quote(member)
         headers, data = self._requester.requestJsonAndCheck("GET", f"{self.url}/memberships/{member}")
         return github.Membership.Membership(self._requester, headers, data, completed=True)
 
@@ -210,6 +245,8 @@ class Team(CompletableGithubObject):
         assert isinstance(repo, github.Repository.Repository) or isinstance(repo, str), repo
         if isinstance(repo, github.Repository.Repository):
             repo = repo._identity  # type: ignore
+        else:
+            repo = urllib.parse.quote(repo)
         try:
             headers, data = self._requester.requestJsonAndCheck(
                 "GET",
@@ -250,7 +287,7 @@ class Team(CompletableGithubObject):
         if isinstance(repo, github.Repository.Repository):
             repo_url_param = repo._identity
         else:
-            repo_url_param = repo
+            repo_url_param = urllib.parse.quote(repo)
         put_parameters = {
             "permission": permission,
         }
@@ -273,6 +310,8 @@ class Team(CompletableGithubObject):
         description: Opt[str] = NotSet,
         permission: Opt[str] = NotSet,
         privacy: Opt[str] = NotSet,
+        parent_team_id: Opt[int] = NotSet,
+        notification_setting: Opt[str] = NotSet,
     ) -> None:
         """
         :calls: `PATCH /teams/{id} <https://docs.github.com/en/rest/reference/teams#update-a-team>`_
@@ -281,8 +320,17 @@ class Team(CompletableGithubObject):
         assert description is NotSet or isinstance(description, str), description
         assert permission is NotSet or isinstance(permission, str), permission
         assert privacy is NotSet or isinstance(privacy, str), privacy
+        assert parent_team_id is NotSet or isinstance(parent_team_id, (int, type(None))), parent_team_id
+        assert notification_setting in ["notifications_enabled", "notifications_disabled", NotSet], notification_setting
         post_parameters = NotSet.remove_unset_items(
-            {"name": name, "description": description, "permission": permission, "privacy": privacy}
+            {
+                "name": name,
+                "description": description,
+                "permission": permission,
+                "privacy": privacy,
+                "parent_team_id": parent_team_id,
+                "notification_setting": notification_setting,
+            }
         )
 
         headers, data = self._requester.requestJsonAndCheck("PATCH", self.url, input=post_parameters)
@@ -402,6 +450,8 @@ class Team(CompletableGithubObject):
             self._name = self._makeStringAttribute(attributes["name"])
         if "description" in attributes:  # pragma no branch
             self._description = self._makeStringAttribute(attributes["description"])
+        if "notification_setting" in attributes:  # pragma no branch
+            self._notification_setting = self._makeStringAttribute(attributes["notification_setting"])
         if "permission" in attributes:  # pragma no branch
             self._permission = self._makeStringAttribute(attributes["permission"])
         if "repos_count" in attributes:  # pragma no branch
